# Welcome to geoca

[![image](https://img.shields.io/pypi/v/geoca.svg)](https://pypi.python.org/pypi/geoca)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

<img src="assets/logo_long.png" alt="logo" style="zoom:30%;" />

**A Python module for CA models based on geo-raster data**

- Free software: MIT License
- Documentation: [https://Haorui-Jiang.github.io/geoca](https://Haorui-Jiang.github.io/geoca)

## Features

- Read raster data from a file, convert the data into a Python list.
- Create a raster template based on the input raster, and replace the data from list into the new raster.
- Running CA models based on raster data to analyze population and other resource migration.
- Reads multiple raster data (.tif) from a folder and stores it in a dictionary.
- Reorganizes data from a list dictionary representing multiple raster data.
